"""Logging Factory class that generates Loguru, Elasticseach, or AsyncElasticsearch class"""
from typing import Union
from .constants.keys import LoggerKeys
from .loggers.elk import Elk
from .loggers.asyncelk import AsyncElk
from .loggers.loguru import Loguru


class Loggers(Loguru):
    """
    The main loggers API which should be used.
    """

    def __new__(cls, **kwargs) -> Union[Loguru, Elk, AsyncElk]:
        if kwargs.get(LoggerKeys.DEBUG.value):
            return Loguru(**kwargs)

        if kwargs.get(LoggerKeys.ASYNC.value):
            return AsyncElk(**kwargs)

        return Elk(**kwargs)
